@@ -1,9 +1,9 @@
 #!/bin/bash
 # libiso8601/test.sh
-#
-#  (c)2009, Laurence Withers, <l@lwithers.me.uk>.
-#  Released under the GNU GPLv3. See file COPYING or
-#  http://www.gnu.org/copyleft/gpl.html for details.
+# 
+#  Copyright: ©2009–2011, Güralp Systems Ltd.
+#  Author: Laurence Withers <lwithers@guralp.com>
+#  License: GPLv3
 #
 
 # Running this script on its own will display a summary of all the
@@ -21,7 +21,7 @@ run_test() {
         return 1
     fi
 
-    LD_LIBRARY_PATH="obj" "${EXE}" "$@" || return 1
+    LD_LIBRARY_PATH="obj:${LD_LIBRARY_PATH}" "${EXE}" "$@" || return 1
     return 0
 }
 
@@ -36,11 +36,12 @@ print_tests() {
         [ -x "${EXE}" ] || continue
         NAME="$(echo "${EXE}" | sed 's,obj/tests/,,')"
         echo -ne "${NAME}\t"
-        LD_LIBRARY_PATH="obj" "${EXE}" --print-summary
+        LD_LIBRARY_PATH="obj:${LD_LIBRARY_PATH}" "${EXE}" --print-summary
     done
 }
 
 
+
 # Main script
 if [ $# -eq 0 ]
 then
@@ -48,7 +49,6 @@ then
     exit 0
 fi
 
-run_test $*
+run_test "$@"
 
-# kate: replace-trailing-space-save true; space-indent true; tab-width 4;
 # vim: expandtab:ts=4:sw=4
