@@ -8,6 +8,10 @@
 #ifndef HEADER_libiso8601
 #define HEADER_libiso8601
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* standard includes, or includes needed for type declarations */
 #include <time.h>
 #include <stdint.h>
