@@ -26,11 +26,7 @@ understood by humans, and vice versa.
 Returns non-0 if \a year is a leap year.
 
 */
-int iso8601_isleap(int year)
-#ifndef DOXYGEN
-    __attribute__((nonnull))
-#endif
-;
+int iso8601_isleap(int year);
 
 
 
