@@ -5,6 +5,10 @@
  *  http://www.gnu.org/copyleft/gpl.html for details.
 */
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
 /* options for text editors
